@@ -5,7 +5,6 @@ import json
 from typing import Optional  # Any, Union
 
 
-from viso_sdk.constants import PREFIX
 from viso_sdk.logging import get_logger
 
 logger = get_logger(name="MQTT")
@@ -15,16 +14,12 @@ DEFAULT_MQTT_HOST = "127.0.0.1"
 DEFAULT_MQTT_PORT = 1883
 
 
-def gen_mqtt_key_local(node_id):
-    return f"{PREFIX.MQTT.LOCAL}_{node_id}"
-
-
 class MqttWrapper(threading.Thread):
     def __init__(self,
                  host: Optional[str] = DEFAULT_MQTT_HOST,
                  port: Optional[int] = DEFAULT_MQTT_PORT,
                  subscribe_topics: Optional[list] = None,
-                 verbose: Optional[bool] = True,
+                 verbose: Optional[bool] = False,
                  username=None,
                  password=None):
         super().__init__()
