@@ -1,3 +1,3 @@
 
 from .redis_wrapper import RedisWrapper as VisoRedis
-from .redis_wrapper import gen_redis_key_local
+from .utils import gen_redis_key_local
