@@ -11,17 +11,12 @@ import numpy as np
 import redis
 
 
-from viso_sdk.constants import PREFIX
 from viso_sdk.logging.logger import get_logger
 
 
 logger = get_logger("REDIS")
 
 
-def gen_redis_key_local(node_id, port):
-    return f"{PREFIX.REDIS.LOCAL}_{node_id}_{port}"
-
-
 class RedisWrapper:
     """Represents a redis client specified for the containers.
 
@@ -42,10 +37,6 @@ class RedisWrapper:
 
         _img_arr = None
 
-    @staticmethod
-    def gen_redis_key_status(node_id, port):
-        return f"{PREFIX.REDIS.STATUS}_{node_id}_{port}"
-
     @staticmethod
     def base64_to_img(b64_bytes: bytes) -> Union[None, np.ndarray]:
         """Convert base64 string to opencv frame"""
